@@ -12,16 +12,20 @@ from langchain_community.tools.cogniswitch.tool import (
 
 
 class CogniswitchToolkit(BaseToolkit):
-    """
-    Toolkit for CogniSwitch.
+    """Toolkit for CogniSwitch.
 
-    Use the toolkit to get all the tools present in the cogniswitch and
-    use them to interact with your knowledge
+    Use the toolkit to get all the tools present in the Cogniswitch and
+    use them to interact with your knowledge.
+
+    Parameters:
+        cs_token: str. The Cogniswitch token.
+        OAI_token: str. The OpenAI API token.
+        apiKey: str. The Cogniswitch OAuth token.
     """
 
-    cs_token: str  # cogniswitch token
-    OAI_token: str  # OpenAI API token
-    apiKey: str  # Cogniswitch OAuth token
+    cs_token: str
+    OAI_token: str
+    apiKey: str
 
     def get_tools(self) -> List[BaseTool]:
         """Get the tools in the toolkit."""
