@@ -9,6 +9,9 @@ from langchain_community.tools.connery import ConneryService
 class ConneryToolkit(BaseToolkit):
     """
     Toolkit with a list of Connery Actions as tools.
+
+    Parameters:
+        tools (List[BaseTool]): The list of Connery Actions.
     """
 
     tools: List[BaseTool]
@@ -19,14 +22,18 @@ class ConneryToolkit(BaseToolkit):
         """
         return self.tools
 
-    @root_validator()
+    @root_validator(pre=True)
     def validate_attributes(cls, values: dict) -> dict:
         """
         Validate the attributes of the ConneryToolkit class.
-        Parameters:
+
+        Args:
             values (dict): The arguments to validate.
         Returns:
             dict: The validated arguments.
+
+        Raises:
+            ValueError: If the 'tools' attribute is not set
         """
 
         if not values.get("tools"):
@@ -38,9 +45,10 @@ class ConneryToolkit(BaseToolkit):
     def create_instance(cls, connery_service: ConneryService) -> "ConneryToolkit":
         """
         Creates a Connery Toolkit using a Connery Service.
+
         Parameters:
             connery_service (ConneryService): The Connery Service
-            to to get the list of Connery Actions.
+                to get the list of Connery Actions.
         Returns:
             ConneryToolkit: The Connery Toolkit.
         """
