@@ -38,6 +38,9 @@ class GmailToolkit(BaseToolkit):
         associated account.
 
         See https://python.langchain.com/docs/security for more information.
+
+    Parameters:
+        api_resource: Optional. The Google API resource. Default is None.
     """
 
     api_resource: Resource = Field(default_factory=build_resource_service)
