@@ -22,12 +22,24 @@ class JiraToolkit(BaseToolkit):
         reading underlying data.
 
         See https://python.langchain.com/docs/security for more information.
+
+    Parameters:
+        tools: List[BaseTool]. The tools in the toolkit. Default is an empty list.
     """
 
     tools: List[BaseTool] = []
 
     @classmethod
     def from_jira_api_wrapper(cls, jira_api_wrapper: JiraAPIWrapper) -> "JiraToolkit":
+        """Create a JiraToolkit from a JiraAPIWrapper.
+
+        Args:
+            jira_api_wrapper: JiraAPIWrapper. The Jira API wrapper.
+
+        Returns:
+            JiraToolkit. The Jira toolkit.
+        """
+
         operations: List[Dict] = [
             {
                 "mode": "jql",
