@@ -1,4 +1,5 @@
 """Playwright web browser toolkit."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, List, Optional, Type, cast
@@ -58,6 +59,10 @@ class PlayWrightBrowserToolkit(BaseToolkit):
         tools.
 
         See https://python.langchain.com/docs/security for more information.
+
+    Parameters:
+        sync_browser: Optional. The sync browser. Default is None.
+        async_browser: Optional. The async browser. Default is None.
     """
 
     sync_browser: Optional["SyncBrowser"] = None
@@ -69,7 +74,7 @@ class PlayWrightBrowserToolkit(BaseToolkit):
         extra = Extra.forbid
         arbitrary_types_allowed = True
 
-    @root_validator
+    @root_validator(pre=True)
     def validate_imports_and_browser_provided(cls, values: dict) -> dict:
         """Check that the arguments are valid."""
         lazy_import_playwright_browsers()
@@ -103,7 +108,15 @@ class PlayWrightBrowserToolkit(BaseToolkit):
         sync_browser: Optional[SyncBrowser] = None,
         async_browser: Optional[AsyncBrowser] = None,
     ) -> PlayWrightBrowserToolkit:
-        """Instantiate the toolkit."""
+        """Instantiate the toolkit.
+
+        Args:
+            sync_browser: Optional. The sync browser. Default is None.
+            async_browser: Optional. The async browser. Default is None.
+
+        Returns:
+            The toolkit.
+        """
         # This is to raise a better error than the forward ref ones Pydantic would have
         lazy_import_playwright_browsers()
         return cls(sync_browser=sync_browser, async_browser=async_browser)
