@@ -13,7 +13,11 @@ from langchain_community.utilities.polygon import PolygonAPIWrapper
 
 
 class PolygonToolkit(BaseToolkit):
-    """Polygon Toolkit."""
+    """Polygon Toolkit.
+
+    Parameters:
+        tools: List[BaseTool]. The tools in the toolkit.
+    """
 
     tools: List[BaseTool] = []
 
@@ -21,6 +25,14 @@ class PolygonToolkit(BaseToolkit):
     def from_polygon_api_wrapper(
         cls, polygon_api_wrapper: PolygonAPIWrapper
     ) -> "PolygonToolkit":
+        """Create a Polygon Toolkit from a Polygon API Wrapper.
+
+        Args:
+            polygon_api_wrapper: PolygonAPIWrapper. The Polygon API Wrapper.
+
+        Returns:
+            PolygonToolkit. The Polygon Toolkit.
+        """
         tools = [
             PolygonAggregates(
                 api_wrapper=polygon_api_wrapper,
