@@ -2,6 +2,9 @@ import importlib
 from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
+    from langchain_community.document_compressors.dashscope_rerank import (
+        DashScopeRerank,
+    )
     from langchain_community.document_compressors.flashrank_rerank import (
         FlashrankRerank,
     )
@@ -17,7 +20,9 @@ if TYPE_CHECKING:
     from langchain_community.document_compressors.rankllm_rerank import (
         RankLLMRerank,
     )
-
+    from langchain_community.document_compressors.volcengine_rerank import (
+        VolcengineRerank,
+    )
 
 _module_lookup = {
     "LLMLinguaCompressor": "langchain_community.document_compressors.llmlingua_filter",
@@ -25,6 +30,8 @@ _module_lookup = {
     "JinaRerank": "langchain_community.document_compressors.jina_rerank",
     "RankLLMRerank": "langchain_community.document_compressors.rankllm_rerank",
     "FlashrankRerank": "langchain_community.document_compressors.flashrank_rerank",
+    "DashScopeRerank": "langchain_community.document_compressors.dashscope_rerank",
+    "VolcengineRerank": "langchain_community.document_compressors.volcengine_rerank",
 }
 
 
@@ -41,4 +48,6 @@ __all__ = [
     "FlashrankRerank",
     "JinaRerank",
     "RankLLMRerank",
+    "DashScopeRerank",
+    "VolcengineRerank",
 ]
