@@ -1,4 +1,5 @@
 import logging
+from pathlib import Path
 from typing import Dict, Iterator, Union
 
 from langchain_core.documents import Document
@@ -13,7 +14,7 @@ class BSHTMLLoader(BaseLoader):
 
     def __init__(
         self,
-        file_path: str,
+        file_path: Union[str, Path],
         open_encoding: Union[str, None] = None,
         bs_kwargs: Union[dict, None] = None,
         get_text_separator: str = "",
@@ -57,7 +58,7 @@ class BSHTMLLoader(BaseLoader):
             title = ""
 
         metadata: Dict[str, Union[str, None]] = {
-            "source": self.file_path,
+            "source": str(self.file_path),
             "title": title,
         }
         yield Document(page_content=text, metadata=metadata)
