@@ -77,7 +77,19 @@ class MongodbLoader(BaseLoader):
 
             # Extract text content from filtered fields or use the entire document
             if self.field_names is not None:
-                fields = {name: doc[name] for name in self.field_names}
+                fields = {}
+                for name in self.field_names:
+                    # Split the field names to handle nested fields
+                    keys = name.split(".")
+                    value = doc
+                    for key in keys:
+                        if key in value:
+                            value = value[key]
+                        else:
+                            value = ""
+                            break
+                    fields[name] = value
+
                 texts = [str(value) for value in fields.values()]
                 text = " ".join(texts)
             else:
