@@ -48,7 +48,11 @@ class GrobidParser(BaseBlobParser):
             )
         soup = BeautifulSoup(xml_data, "xml")
         sections = soup.find_all("div")
-        title = soup.find_all("title")[0].text
+        titles = soup.find_all("title")
+        if titles:
+            title = titles[0].text
+        else:
+            title = "No title found"
         chunks = []
         for section in sections:
             sect = section.find("head")
