@@ -1,11 +1,13 @@
 """Loads YouTube transcript."""
+
 from __future__ import annotations
 
 import logging
 from enum import Enum
 from pathlib import Path
-from typing import Any, Dict, List, Optional, Sequence, Union
+from typing import Any, Dict, Generator, List, Optional, Sequence, Union
 from urllib.parse import parse_qs, urlparse
+from xml.etree.ElementTree import ParseError  # OK: trusted-source
 
 from langchain_core.documents import Document
 from langchain_core.pydantic_v1 import root_validator
@@ -27,6 +29,8 @@ class GoogleApiClient:
     As the google api expects credentials you need to set up a google account and
     register your Service. "https://developers.google.com/docs/api/quickstart/python"
 
+    *Security Note*: Note that parsing of the transcripts relies on the standard
+        xml library but the input is viewed as trusted in this case.
 
 
     Example:
@@ -46,7 +50,7 @@ class GoogleApiClient:
     def __post_init__(self) -> None:
         self.creds = self._load_credentials()
 
-    @root_validator
+    @root_validator(pre=True)
     def validate_channel_or_videoIds_is_set(
         cls, values: Dict[str, Any]
     ) -> Dict[str, Any]:
@@ -99,8 +103,8 @@ class GoogleApiClient:
         return creds
 
 
-ALLOWED_SCHEMAS = {"http", "https"}
-ALLOWED_NETLOCK = {
+ALLOWED_SCHEMES = {"http", "https"}
+ALLOWED_NETLOCS = {
     "youtu.be",
     "m.youtube.com",
     "youtube.com",
@@ -111,13 +115,13 @@ ALLOWED_NETLOCK = {
 
 
 def _parse_video_id(url: str) -> Optional[str]:
-    """Parse a youtube url and return the video id if valid, otherwise None."""
+    """Parse a YouTube URL and return the video ID if valid, otherwise None."""
     parsed_url = urlparse(url)
 
-    if parsed_url.scheme not in ALLOWED_SCHEMAS:
+    if parsed_url.scheme not in ALLOWED_SCHEMES:
         return None
 
-    if parsed_url.netloc not in ALLOWED_NETLOCK:
+    if parsed_url.netloc not in ALLOWED_NETLOCS:
         return None
 
     path = parsed_url.path
@@ -141,14 +145,15 @@ def _parse_video_id(url: str) -> Optional[str]:
 
 
 class TranscriptFormat(Enum):
-    """Transcript format."""
+    """Output formats of transcripts from `YoutubeLoader`."""
 
     TEXT = "text"
     LINES = "lines"
+    CHUNKS = "chunks"
 
 
 class YoutubeLoader(BaseLoader):
-    """Load `YouTube` transcripts."""
+    """Load `YouTube` video transcripts."""
 
     def __init__(
         self,
@@ -158,9 +163,11 @@ class YoutubeLoader(BaseLoader):
         translation: Optional[str] = None,
         transcript_format: TranscriptFormat = TranscriptFormat.TEXT,
         continue_on_failure: bool = False,
+        chunk_size_seconds: int = 120,
     ):
         """Initialize with YouTube video ID."""
         self.video_id = video_id
+        self._metadata = {"source": video_id}
         self.add_video_info = add_video_info
         self.language = language
         if isinstance(language, str):
@@ -170,25 +177,69 @@ class YoutubeLoader(BaseLoader):
         self.translation = translation
         self.transcript_format = transcript_format
         self.continue_on_failure = continue_on_failure
+        self.chunk_size_seconds = chunk_size_seconds
 
     @staticmethod
     def extract_video_id(youtube_url: str) -> str:
-        """Extract video id from common YT urls."""
+        """Extract video ID from common YouTube URLs."""
         video_id = _parse_video_id(youtube_url)
         if not video_id:
             raise ValueError(
-                f"Could not determine the video ID for the URL {youtube_url}"
+                f'Could not determine the video ID for the URL "{youtube_url}".'
             )
         return video_id
 
     @classmethod
     def from_youtube_url(cls, youtube_url: str, **kwargs: Any) -> YoutubeLoader:
-        """Given youtube URL, load video."""
+        """Given a YouTube URL, construct a loader.
+        See `YoutubeLoader()` constructor for a list of keyword arguments.
+        """
         video_id = cls.extract_video_id(youtube_url)
         return cls(video_id, **kwargs)
 
+    def _make_chunk_document(
+        self, chunk_pieces: List[Dict], chunk_start_seconds: int
+    ) -> Document:
+        """Create Document from chunk of transcript pieces."""
+        m, s = divmod(chunk_start_seconds, 60)
+        h, m = divmod(m, 60)
+        return Document(
+            page_content=" ".join(
+                map(lambda chunk_piece: chunk_piece["text"].strip(" "), chunk_pieces)
+            ),
+            metadata={
+                **self._metadata,
+                "start_seconds": chunk_start_seconds,
+                "start_timestamp": f"{h:02d}:{m:02d}:{s:02d}",
+                "source":
+                # replace video ID with URL to start time
+                f"https://www.youtube.com/watch?v={self.video_id}"
+                f"&t={chunk_start_seconds}s",
+            },
+        )
+
+    def _get_transcript_chunks(
+        self, transcript_pieces: List[Dict]
+    ) -> Generator[Document, None, None]:
+        chunk_pieces: List[Dict[str, Any]] = []
+        chunk_start_seconds = 0
+        chunk_time_limit = self.chunk_size_seconds
+        for transcript_piece in transcript_pieces:
+            piece_end = transcript_piece["start"] + transcript_piece["duration"]
+            if piece_end > chunk_time_limit:
+                if chunk_pieces:
+                    yield self._make_chunk_document(chunk_pieces, chunk_start_seconds)
+                chunk_pieces = []
+                chunk_start_seconds = chunk_time_limit
+                chunk_time_limit += self.chunk_size_seconds
+
+            chunk_pieces.append(transcript_piece)
+
+        if len(chunk_pieces) > 0:
+            yield self._make_chunk_document(chunk_pieces, chunk_start_seconds)
+
     def load(self) -> List[Document]:
-        """Load documents."""
+        """Load YouTube transcripts into `Document` objects."""
         try:
             from youtube_transcript_api import (
                 NoTranscriptFound,
@@ -197,17 +248,15 @@ class YoutubeLoader(BaseLoader):
             )
         except ImportError:
             raise ImportError(
-                "Could not import youtube_transcript_api python package. "
+                'Could not import "youtube_transcript_api" Python package. '
                 "Please install it with `pip install youtube-transcript-api`."
             )
 
-        metadata = {"source": self.video_id}
-
         if self.add_video_info:
             # Get more video meta info
             # Such as title, description, thumbnail url, publish_date
             video_info = self._get_video_info()
-            metadata.update(video_info)
+            self._metadata.update(video_info)
 
         try:
             transcript_list = YouTubeTranscriptApi.list_transcripts(self.video_id)
@@ -222,31 +271,45 @@ class YoutubeLoader(BaseLoader):
         if self.translation is not None:
             transcript = transcript.translate(self.translation)
 
-        transcript_pieces = transcript.fetch()
+        transcript_pieces: List[Dict[str, Any]] = transcript.fetch()
 
         if self.transcript_format == TranscriptFormat.TEXT:
-            transcript = " ".join([t["text"].strip(" ") for t in transcript_pieces])
-            return [Document(page_content=transcript, metadata=metadata)]
-        elif self.transcript_format == TranscriptFormat.LINES:
-            return [
-                Document(
-                    page_content=t["text"].strip(" "),
-                    metadata=dict((key, t[key]) for key in t if key != "text"),
+            transcript = " ".join(
+                map(
+                    lambda transcript_piece: transcript_piece["text"].strip(" "),
+                    transcript_pieces,
                 )
-                for t in transcript_pieces
-            ]
+            )
+            return [Document(page_content=transcript, metadata=self._metadata)]
+        elif self.transcript_format == TranscriptFormat.LINES:
+            return list(
+                map(
+                    lambda transcript_piece: Document(
+                        page_content=transcript_piece["text"].strip(" "),
+                        metadata=dict(
+                            filter(
+                                lambda item: item[0] != "text", transcript_piece.items()
+                            )
+                        ),
+                    ),
+                    transcript_pieces,
+                )
+            )
+        elif self.transcript_format == TranscriptFormat.CHUNKS:
+            return list(self._get_transcript_chunks(transcript_pieces))
+
         else:
             raise ValueError("Unknown transcript format.")
 
-    def _get_video_info(self) -> dict:
+    def _get_video_info(self) -> Dict:
         """Get important video information.
 
-        Components are:
+        Components include:
             - title
             - description
-            - thumbnail url,
+            - thumbnail URL,
             - publish_date
-            - channel_author
+            - channel author
             - and more.
         """
         try:
@@ -254,7 +317,7 @@ class YoutubeLoader(BaseLoader):
 
         except ImportError:
             raise ImportError(
-                "Could not import pytube python package. "
+                'Could not import "pytube" Python package. '
                 "Please install it with `pip install pytube`."
             )
         yt = YouTube(f"https://www.youtube.com/watch?v={self.video_id}")
@@ -328,7 +391,7 @@ class GoogleApiYoutubeLoader(BaseLoader):
 
         return build("youtube", "v3", credentials=creds)
 
-    @root_validator
+    @root_validator(pre=True)
     def validate_channel_or_videoIds_is_set(
         cls, values: Dict[str, Any]
     ) -> Dict[str, Any]:
@@ -377,6 +440,14 @@ class GoogleApiYoutubeLoader(BaseLoader):
         channel_id = response["items"][0]["id"]["channelId"]
         return channel_id
 
+    def _get_uploads_playlist_id(self, channel_id: str) -> str:
+        request = self.youtube_client.channels().list(
+            part="contentDetails",
+            id=channel_id,
+        )
+        response = request.execute()
+        return response["items"][0]["contentDetails"]["relatedPlaylists"]["uploads"]
+
     def _get_document_for_channel(self, channel: str, **kwargs: Any) -> List[Document]:
         try:
             from youtube_transcript_api import (
@@ -392,10 +463,11 @@ class GoogleApiYoutubeLoader(BaseLoader):
             )
 
         channel_id = self._get_channel_id(channel)
-        request = self.youtube_client.search().list(
+        uploads_playlist_id = self._get_uploads_playlist_id(channel_id)
+        request = self.youtube_client.playlistItems().list(
             part="id,snippet",
-            channelId=channel_id,
-            maxResults=50,  # adjust this value to retrieve more or fewer videos
+            playlistId=uploads_playlist_id,
+            maxResults=50,
         )
         video_ids = []
         while request is not None:
@@ -403,23 +475,20 @@ class GoogleApiYoutubeLoader(BaseLoader):
 
             # Add each video ID to the list
             for item in response["items"]:
-                if not item["id"].get("videoId"):
-                    continue
-                meta_data = {"videoId": item["id"]["videoId"]}
+                video_id = item["snippet"]["resourceId"]["videoId"]
+                meta_data = {"videoId": video_id}
                 if self.add_video_info:
                     item["snippet"].pop("thumbnails")
                     meta_data.update(item["snippet"])
                 try:
-                    page_content = self._get_transcripe_for_video_id(
-                        item["id"]["videoId"]
-                    )
+                    page_content = self._get_transcripe_for_video_id(video_id)
                     video_ids.append(
                         Document(
                             page_content=page_content,
                             metadata=meta_data,
                         )
                     )
-                except (TranscriptsDisabled, NoTranscriptFound) as e:
+                except (TranscriptsDisabled, NoTranscriptFound, ParseError) as e:
                     if self.continue_on_failure:
                         logger.error(
                             "Error fetching transscript "
