@@ -1,7 +1,7 @@
 from typing import Dict
 
-from langchain_core.pydantic_v1 import Field, SecretStr, root_validator
-from langchain_core.utils import convert_to_secret_str, get_from_dict_or_env
+from langchain_core.pydantic_v1 import Field, SecretStr
+from langchain_core.utils import convert_to_secret_str, get_from_dict_or_env, pre_init
 
 from langchain_community.embeddings.openai import OpenAIEmbeddings
 from langchain_community.utils.openai import is_openai_v1
@@ -38,7 +38,7 @@ class OctoAIEmbeddings(OpenAIEmbeddings):
     def lc_secrets(self) -> Dict[str, str]:
         return {"octoai_api_token": "OCTOAI_API_TOKEN"}
 
-    @root_validator()
+    @pre_init
     def validate_environment(cls, values: dict) -> dict:
         """Validate that api key and python package exists in environment."""
         values["endpoint_url"] = get_from_dict_or_env(
