@@ -52,6 +52,16 @@ include_docs_query = (
 
 
 def clean_string_values(text: str) -> str:
+    """Clean string values for schema.
+
+    Cleans the input text by replacing newline and carriage return characters.
+
+    Args:
+        text (str): The input text to clean.
+
+    Returns:
+        str: The cleaned text.
+    """
     return text.replace("\n", " ").replace("\r", " ")
 
 
@@ -63,6 +73,12 @@ def value_sanitize(d: Any) -> Any:
     generating answers in a LLM context. These properties, if left in
     results, can occupy significant context space and detract from
     the LLM's performance by introducing unnecessary noise and cost.
+
+    Args:
+        d (Any): The input dictionary or list to sanitize.
+
+    Returns:
+        Any: The sanitized dictionary or list.
     """
     if isinstance(d, dict):
         new_dict = {}
@@ -271,6 +287,10 @@ def _format_schema(schema: Dict, is_enhanced: bool) -> str:
     )
 
 
+def _remove_backticks(text: str) -> str:
+    return text.replace("`", "")
+
+
 class Neo4jGraph(GraphStore):
     """Neo4j database wrapper for various graph operations.
 
@@ -382,7 +402,15 @@ class Neo4jGraph(GraphStore):
         return self.structured_schema
 
     def query(self, query: str, params: dict = {}) -> List[Dict[str, Any]]:
-        """Query Neo4j database."""
+        """Query Neo4j database.
+
+        Args:
+            query (str): The Cypher query to execute.
+            params (dict): The parameters to pass to the query.
+
+        Returns:
+            List[Dict[str, Any]]: The list of dictionaries containing the query results.
+        """
         from neo4j import Query
         from neo4j.exceptions import CypherSyntaxError
 
@@ -527,10 +555,11 @@ class Neo4jGraph(GraphStore):
                     el["labelsOrTypes"] == [BASE_ENTITY_LABEL]
                     and el["properties"] == ["id"]
                     for el in self.structured_schema.get("metadata", {}).get(
-                        "constraint"
+                        "constraint", []
                     )
                 ]
             )
+
             if not constraint_exists:
                 # Create constraint
                 self.query(
@@ -547,6 +576,9 @@ class Neo4jGraph(GraphStore):
                     document.source.page_content.encode("utf-8")
                 ).hexdigest()
 
+            # Remove backticks from node types
+            for node in document.nodes:
+                node.type = _remove_backticks(node.type)
             # Import nodes
             self.query(
                 node_import_query,
@@ -562,10 +594,12 @@ class Neo4jGraph(GraphStore):
                     "data": [
                         {
                             "source": el.source.id,
-                            "source_label": el.source.type,
+                            "source_label": _remove_backticks(el.source.type),
                             "target": el.target.id,
-                            "target_label": el.target.type,
-                            "type": el.type.replace(" ", "_").upper(),
+                            "target_label": _remove_backticks(el.target.type),
+                            "type": _remove_backticks(
+                                el.type.replace(" ", "_").upper()
+                            ),
                             "properties": el.properties,
                         }
                         for el in document.relationships
