@@ -123,6 +123,9 @@ class _OllamaCommon(BaseLanguageModel):
 
     See the [Ollama documents](https://github.com/ollama/ollama/blob/main/docs/faq.md#how-do-i-keep-a-model-loaded-in-memory-or-make-it-unload-immediately)"""
 
+    raw: Optional[bool] = None
+    """raw or not."""
+
     headers: Optional[dict] = None
     """Additional headers to pass to endpoint (e.g. Authorization, Referer).
     This is useful when Ollama is hosted on cloud services that require
@@ -154,6 +157,7 @@ class _OllamaCommon(BaseLanguageModel):
             "system": self.system,
             "template": self.template,
             "keep_alive": self.keep_alive,
+            "raw": self.raw,
         }
 
     @property
@@ -227,7 +231,6 @@ class _OllamaCommon(BaseLanguageModel):
                 "images": payload.get("images", []),
                 **params,
             }
-
         response = requests.post(
             url=api_url,
             headers={
@@ -369,12 +372,9 @@ class _OllamaCommon(BaseLanguageModel):
 
 class Ollama(BaseLLM, _OllamaCommon):
     """Ollama locally runs large language models.
-
     To use, follow the instructions at https://ollama.ai/.
-
     Example:
         .. code-block:: python
-
             from langchain_community.llms import Ollama
             ollama = Ollama(model="llama2")
     """
@@ -398,17 +398,13 @@ class Ollama(BaseLLM, _OllamaCommon):
         **kwargs: Any,
     ) -> LLMResult:
         """Call out to Ollama's generate endpoint.
-
         Args:
             prompt: The prompt to pass into the model.
             stop: Optional list of stop words to use when generating.
-
         Returns:
             The string generated by the model.
-
         Example:
             .. code-block:: python
-
                 response = ollama("Tell me a joke.")
         """
         # TODO: add caching here.
@@ -434,17 +430,13 @@ class Ollama(BaseLLM, _OllamaCommon):
         **kwargs: Any,
     ) -> LLMResult:
         """Call out to Ollama's generate endpoint.
-
         Args:
             prompt: The prompt to pass into the model.
             stop: Optional list of stop words to use when generating.
-
         Returns:
             The string generated by the model.
-
         Example:
             .. code-block:: python
-
                 response = ollama("Tell me a joke.")
         """
         # TODO: add caching here.
