@@ -93,9 +93,9 @@ class OpenLLM(LLM):
     """Keyword arguments to be passed to openllm.LLM"""
 
     _runner: Optional[openllm.LLMRunner] = PrivateAttr(default=None)
-    _client: Union[
-        openllm.client.HTTPClient, openllm.client.GrpcClient, None
-    ] = PrivateAttr(default=None)
+    _client: Union[openllm.client.HTTPClient, openllm.client.GrpcClient, None] = (
+        PrivateAttr(default=None)
+    )
 
     class Config:
         extra = "forbid"
@@ -108,8 +108,7 @@ class OpenLLM(LLM):
         model_id: Optional[str] = ...,
         embedded: Literal[True, False] = ...,
         **llm_kwargs: Any,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     @overload
     def __init__(
@@ -118,8 +117,7 @@ class OpenLLM(LLM):
         server_url: str = ...,
         server_type: Literal["grpc", "http"] = ...,
         **llm_kwargs: Any,
-    ) -> None:
-        ...
+    ) -> None: ...
 
     def __init__(
         self,
