@@ -10,6 +10,8 @@ from langchain_community.utilities.arxiv import ArxivAPIWrapper
 
 
 class ArxivInput(BaseModel):
+    """Input for the Arxiv tool."""
+
     query: str = Field(description="search query to look up")
 
 
@@ -25,7 +27,7 @@ class ArxivQueryRun(BaseTool):
         "from scientific articles on arxiv.org. "
         "Input should be a search query."
     )
-    api_wrapper: ArxivAPIWrapper = Field(default_factory=ArxivAPIWrapper)
+    api_wrapper: ArxivAPIWrapper = Field(default_factory=ArxivAPIWrapper)  # type: ignore[arg-type]
     args_schema: Type[BaseModel] = ArxivInput
 
     def _run(
