@@ -2,6 +2,7 @@
 
 from typing import Optional, Type
 
+from langchain_core._api.deprecation import deprecated
 from langchain_core.callbacks import CallbackManagerForToolRun
 from langchain_core.pydantic_v1 import BaseModel, Field
 from langchain_core.tools import BaseTool
@@ -15,6 +16,11 @@ class GooglePlacesSchema(BaseModel):
     query: str = Field(..., description="Query for google maps")
 
 
+@deprecated(
+    since="0.0.33",
+    removal="0.3.0",
+    alternative_import="langchain_google_community.GooglePlacesTool",
+)
 class GooglePlacesTool(BaseTool):
     """Tool that queries the Google places API."""
 
@@ -25,7 +31,7 @@ class GooglePlacesTool(BaseTool):
         "discover addressed from ambiguous text. "
         "Input should be a search query."
     )
-    api_wrapper: GooglePlacesAPIWrapper = Field(default_factory=GooglePlacesAPIWrapper)
+    api_wrapper: GooglePlacesAPIWrapper = Field(default_factory=GooglePlacesAPIWrapper)  # type: ignore[arg-type]
     args_schema: Type[BaseModel] = GooglePlacesSchema
 
     def _run(
