@@ -1,10 +1,12 @@
 """Polygon IO tools."""
 
+from langchain_community.tools.polygon.aggregates import PolygonAggregates
 from langchain_community.tools.polygon.financials import PolygonFinancials
 from langchain_community.tools.polygon.last_quote import PolygonLastQuote
 from langchain_community.tools.polygon.ticker_news import PolygonTickerNews
 
 __all__ = [
+    "PolygonAggregates",
     "PolygonFinancials",
     "PolygonLastQuote",
     "PolygonTickerNews",
