@@ -1,16 +1,23 @@
 """Tool for the SearxNG search API."""
-from typing import Optional
+
+from typing import Optional, Type
 
 from langchain_core.callbacks import (
     AsyncCallbackManagerForToolRun,
     CallbackManagerForToolRun,
 )
-from langchain_core.pydantic_v1 import Extra, Field
+from langchain_core.pydantic_v1 import BaseModel, Extra, Field
 from langchain_core.tools import BaseTool
 
 from langchain_community.utilities.searx_search import SearxSearchWrapper
 
 
+class SearxSearchQueryInput(BaseModel):
+    """Input for the SearxSearch tool."""
+
+    query: str = Field(description="query to look up on searx")
+
+
 class SearxSearchRun(BaseTool):
     """Tool that queries a Searx instance."""
 
@@ -22,6 +29,7 @@ class SearxSearchRun(BaseTool):
     )
     wrapper: SearxSearchWrapper
     kwargs: dict = Field(default_factory=dict)
+    args_schema: Type[BaseModel] = SearxSearchQueryInput
 
     def _run(
         self,
