@@ -18,6 +18,8 @@ class SlackGetMessageSchema(BaseModel):
 
 
 class SlackGetMessage(SlackBaseTool):
+    """Tool that gets Slack messages."""
+
     name: str = "get_messages"
     description: str = "Use this tool to get messages from a channel."
 
@@ -37,6 +39,6 @@ class SlackGetMessage(SlackBaseTool):
                 for message in messages
                 if "user" in message and "text" in message and "ts" in message
             ]
-            return json.dumps(filtered_messages)
+            return json.dumps(filtered_messages, ensure_ascii=False)
         except Exception as e:
             return "Error creating conversation: {}".format(e)
