@@ -20,8 +20,8 @@ class YouInput(BaseModel):
 class YouSearchTool(BaseTool):
     """Tool that searches the you.com API."""
 
-    name = "you_search"
-    description = (
+    name: str = "you_search"
+    description: str = (
         "The YOU APIs make LLMs and search experiences more factual and"
         "up to date with realtime web data."
     )
