@@ -36,6 +36,16 @@ async def wrapped_response_future(
 
 
 async def aexecute_cql(session: Session, query: str, **kwargs: Any) -> Any:
+    """Execute a CQL query asynchronously.
+
+    Args:
+        session: The Cassandra session to use.
+        query: The CQL query to execute.
+        **kwargs: Additional keyword arguments to pass to the session execute method.
+
+    Returns:
+        The result of the query.
+    """
     return await wrapped_response_future(session.execute_async, query, **kwargs)
 
 
