@@ -8,7 +8,7 @@ from langchain_core.pydantic_v1 import BaseModel, Field
 class MojeekSearchAPIWrapper(BaseModel):
     api_key: str
     search_kwargs: dict = Field(default_factory=dict)
-    api_url = "https://api.mojeek.com/search"
+    api_url: str = "https://api.mojeek.com/search"
 
     def run(self, query: str) -> str:
         search_results = self._search(query)
