@@ -2,6 +2,7 @@
 Util that calls several of Polygon's stock market REST APIs.
 Docs: https://polygon.io/docs/stocks/getting-started
 """
+
 import json
 from typing import Any, Dict, Optional
 
@@ -17,7 +18,7 @@ class PolygonAPIWrapper(BaseModel):
 
     polygon_api_key: Optional[str] = None
 
-    @root_validator()
+    @root_validator(pre=True)
     def validate_environment(cls, values: Dict) -> Dict:
         """Validate that api key in environment."""
         polygon_api_key = get_from_dict_or_env(
