@@ -1,4 +1,5 @@
 """SQLAlchemy wrapper around a database."""
+
 from __future__ import annotations
 
 from typing import Any, Dict, Iterable, List, Literal, Optional, Sequence, Union
@@ -14,7 +15,7 @@ from sqlalchemy import (
     select,
     text,
 )
-from sqlalchemy.engine import Engine, Result
+from sqlalchemy.engine import URL, Engine, Result
 from sqlalchemy.exc import ProgrammingError, SQLAlchemyError
 from sqlalchemy.schema import CreateTable
 from sqlalchemy.sql.expression import Executable
@@ -128,7 +129,10 @@ class SQLDatabase:
 
     @classmethod
     def from_uri(
-        cls, database_uri: str, engine_args: Optional[dict] = None, **kwargs: Any
+        cls,
+        database_uri: Union[str, URL],
+        engine_args: Optional[dict] = None,
+        **kwargs: Any,
     ) -> SQLDatabase:
         """Construct a SQLAlchemy engine from URI."""
         _engine_args = engine_args or {}
@@ -198,10 +202,10 @@ class SQLDatabase:
             from dbruntime.databricks_repl_context import get_context
 
             context = get_context()
-        except ImportError:
-            pass
+            default_host = context.browserHostName
+        except (ImportError, AttributeError):
+            default_host = None
 
-        default_host = context.browserHostName if context else None
         if host is None:
             host = get_from_env("host", "DATABRICKS_HOST", default_host)
 
@@ -334,7 +338,7 @@ class SQLDatabase:
                 continue
 
             # Ignore JSON datatyped columns
-            for k, v in table.columns.items():
+            for k, v in table.columns.items():  # AttributeError: items in sqlalchemy v1
                 if type(v.type) is NullType:
                     table._columns.remove(v)
 
