@@ -11,7 +11,6 @@ from typing import (
     List,
     Optional,
     Tuple,
-    TypeVar,
     Union,
 )
 
@@ -47,8 +46,6 @@ class CosmosDBVectorSearchType(str, Enum):
     """HNSW vector index"""
 
 
-CosmosDBDocumentType = TypeVar("CosmosDBDocumentType", bound=Dict[str, Any])
-
 logger = logging.getLogger(__name__)
 
 DEFAULT_INSERT_BATCH_SIZE = 128
@@ -64,7 +61,8 @@ class AzureCosmosDBVectorSearch(VectorStore):
     Example:
         . code-block:: python
 
-            from langchain_community.vectorstores import AzureCosmosDBVectorSearch
+            from langchain_community.vectorstores import
+            AzureCosmosDBVectorSearch
             from langchain_community.embeddings.openai import OpenAIEmbeddings
             from pymongo import MongoClient
 
@@ -76,12 +74,13 @@ class AzureCosmosDBVectorSearch(VectorStore):
 
     def __init__(
         self,
-        collection: Collection[CosmosDBDocumentType],
+        collection: Collection,
         embedding: Embeddings,
         *,
         index_name: str = "vectorSearchIndex",
         text_key: str = "textContent",
         embedding_key: str = "vectorContent",
+        application_name: str = "LANGCHAIN_PYTHON",
     ):
         """Constructor for AzureCosmosDBVectorSearch
 
@@ -99,6 +98,7 @@ class AzureCosmosDBVectorSearch(VectorStore):
         self._index_name = index_name
         self._text_key = text_key
         self._embedding_key = embedding_key
+        self._application_name = application_name
 
     @property
     def embeddings(self) -> Embeddings:
@@ -122,7 +122,8 @@ class AzureCosmosDBVectorSearch(VectorStore):
         application_name: str = "LANGCHAIN_PYTHON",
         **kwargs: Any,
     ) -> AzureCosmosDBVectorSearch:
-        """Creates an Instance of AzureCosmosDBVectorSearch from a Connection String
+        """Creates an Instance of AzureCosmosDBVectorSearch
+        from a Connection String
 
         Args:
             connection_string: The MongoDB vCore instance connection string
@@ -357,7 +358,7 @@ class AzureCosmosDBVectorSearch(VectorStore):
         texts: List[str],
         embedding: Embeddings,
         metadatas: Optional[List[dict]] = None,
-        collection: Optional[Collection[CosmosDBDocumentType]] = None,
+        collection: Optional[Collection] = None,
         **kwargs: Any,
     ) -> AzureCosmosDBVectorSearch:
         if collection is None:
@@ -581,5 +582,5 @@ class AzureCosmosDBVectorSearch(VectorStore):
         )
         return docs
 
-    def get_collection(self) -> Collection[CosmosDBDocumentType]:
+    def get_collection(self) -> Collection:
         return self._collection
