@@ -1053,7 +1053,7 @@ class Milvus(VectorStore):
         pks = [item.get(self._primary_field) for item in query_result]
         return pks
 
-    def upsert(
+    def upsert(  # type: ignore[override]
         self,
         ids: Optional[List[str]] = None,
         documents: List[Document] | None = None,
@@ -1076,6 +1076,7 @@ class Milvus(VectorStore):
             return None
 
         if ids is not None and len(ids):
+            kwargs["ids"] = ids
             try:
                 self.delete(ids=ids)
             except MilvusException:
